@@ -3,6 +3,7 @@ from unittest import mock
 import responses  # type: ignore
 import json
 import gzip
+import os
 from tests.cli_test_case import CliTestCase
 
 
@@ -11,6 +12,7 @@ class CypressTest(CliTestCase):
         '../data/cypress/').resolve()
 
     @responses.activate
+    @mock.patch.dict(os.environ, {"LAUNCHABLE_TOKEN": CliTestCase.launchable_token})
     def test_record_test_cypress(self):
         # test-result.xml was generated used to cypress-io/cypress-example-kitchensink
         # cypress run --reporter junit report.xml
@@ -18,14 +20,14 @@ class CypressTest(CliTestCase):
                           'cypress', str(self.test_files_dir) + "/test-result.xml")
         self.assertEqual(result.exit_code, 0)
 
-        payload = json.loads(gzip.decompress(
-            b''.join(responses.calls[1].request.body)).decode())
+        payload = json.loads(gzip.decompress(responses.calls[1].request.body).decode())
         expected = self.load_json_from_file(
             self.test_files_dir.joinpath('record_test_result.json'))
 
         self.assert_json_orderless_equal(expected, payload)
 
     @responses.activate
+    @mock.patch.dict(os.environ, {"LAUNCHABLE_TOKEN": CliTestCase.launchable_token})
     def test_subset_cypress(self):
         # test-report.xml is outputed from cypress/integration/examples/window.spec.js, so set it
         pipe = "cypress/integration/examples/window.spec.js"
@@ -40,6 +42,7 @@ class CypressTest(CliTestCase):
         self.assert_json_orderless_equal(expected, payload)
 
     @responses.activate
+    @mock.patch.dict(os.environ, {"LAUNCHABLE_TOKEN": CliTestCase.launchable_token})
     def test_empty_xml(self):
         # parse empty test report XML
         result = self.cli('record', 'tests',  '--session', self.session,
